/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEi for the 3D integration at all eps-orders of the Cf^2 structure, subregion a. 
 * Example: I3EM2r ('I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd order, third integration over 'r' (rescaled q)) contains various logs of FXi functions
 * evaluated at x=0,c=0,s5=0, i.e. with all the deltas from +-distributions except the one associated with 'r', multiplied with the correct X functions' eps-powers to arrive at eps^-2. 
 */

#include <3Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I3EM3r(double r, double s, double s6) {
	return 0; //leading order indep
}
double I3EM2r(double r, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(r,-1)*((-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) +
	          log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) -
	          log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) - XCfE1(0,0,s,0,s6) + XCfE1(r,0,s,0,s6)))/4.;
}
double I3EM1r(double r, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(r,-1)*((mexp*n*log(r)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) -
            log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0))) -
         2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) -
            pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) +
            pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)))*XCfE0(s,0,s6) -
      (mexp*n*log(r) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
         log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6) +
      (mexp*n*log(r) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) +
         log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE1(r,0,s,0,s6) - XCfE2(0,0,s,0,s6) + XCfE2(r,0,s,0,s6)))/4.;
}
double I3E0r(double r, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(r,-1)*((-3*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
            log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),0)) +
            log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),0)))*pow(mexp,2)*pow(n,2)*pow(log(r),2) -
         12*mexp*n*log(r)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) +
            pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) -
            pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)) -
         16*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) -
            pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),3) +
            pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),3)))*XCfE0(s,0,s6) +
      3*(-((2*mexp*n*log(r)*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
                 log(FA2b(0,0,t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(r),2) +
              4*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
                 pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2)))*XCfE1(0,0,s,0,s6)) +
         (2*mexp*n*log(r)*(log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) +
               log(FA2b(q(r),0,t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(r),2) +
            4*(pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) +
               pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)))*XCfE1(r,0,s,0,s6) -
         2*(mexp*n*log(r) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE2(0,0,s,0,s6) +
         2*(mexp*n*log(r) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) +
            log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE2(r,0,s,0,s6)) - 6*XCfE3(0,0,s,0,s6) + 6*XCfE3(r,0,s,0,s6)))/24.;
}

double I3EM3x(double x, double s, double s6) {
	return 0; //leading order indep
}
double I3EM2x(double x, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(x,-1)*((-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) +
	          log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) -
	          log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE0(s,0,s6) - XCfE1(0,0,s,0,s6) + XCfE1(0,x,s,0,s6)))/2.;
}
double I3EM1x(double x, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(x,-1)*(-2*(mexp*n*log(x)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) +
            log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
            log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0))) +
         pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) -
         pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) +
         pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE0(s,0,s6) -
      (2*mexp*n*log(x) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
         log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6) +
      (2*mexp*n*log(x) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) +
         log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE1(0,x,s,0,s6) - XCfE2(0,0,s,0,s6) + XCfE2(0,x,s,0,s6)))/2.;
}
double I3E0x(double x, double s, double s6) {
	return -(pow(mexp,-1)*pow(n,-1)*pow(x,-1)*(2*(3*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
            log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),0)) +
            log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0)))*pow(mexp,2)*pow(n,2)*pow(log(x),2) +
         6*mexp*n*log(x)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) +
            pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) -
            pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2)) +
         4*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) -
            pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),3) +
            pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),3)))*XCfE0(s,0,s6) +
      3*(2*(mexp*n*log(x)*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
               log(FA2b(0,0,t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(x),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
            pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*
          XCfE1(0,0,s,0,s6) - 2*(mexp*n*log(x)*(log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) +
               log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(x),2) +
            pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) +
            pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE1(0,x,s,0,s6) +
         (2*mexp*n*log(x) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE2(0,0,s,0,s6) -
         (2*mexp*n*log(x) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) +
            log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE2(0,x,s,0,s6) + XCfE3(0,0,s,0,s6) - XCfE3(0,x,s,0,s6))))/6.;

}

double I3EM3c(double c, double s, double s6) {
	return 0; //leading order is c-indep
}
double I3EM2c(double c, double s, double s6) {
	return (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
		     log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*
		   pow(c,-1)*pow(mexp,-2)*pow(n,-2)*XCfE0(s,0,s6);
}
double I3EM1c(double c, double s, double s6) {
	return pow(c,-1)*pow(mexp,-2)*pow(n,-2)*(-2*(2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) -
	        pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) -
	        pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0(s,0,s6) +
	     (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*
	      XCfE1(0,0,s,0,s6));
}
double I3E0c(double c, double s, double s6) {
	return (pow(c,-1)*pow(mexp,-2)*pow(n,-2)*(8*(3*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
            log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) +
            log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*pow(log(c),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) -
         pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),3) +
         pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),3) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3) -
         3*log(c)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) -
            pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) +
            pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2)) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),3))*
       XCfE0(s,0,s6) - 6*(2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
            log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) +
            log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) - pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
         pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) -
         pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) +
         pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE1(0,0,s,0,s6) +
      3*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
         log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) +
         log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE2(0,0,s,0,s6)))/3.;
}

double I3EM3s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(XCfE0(s,0,s6) - XCfE0(s,s5,s6)))/2.;
}
double I3EM2s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*((-2*log(s5) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) +
	          log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) +
	       (2*log(s5) - log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) -
	          log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE0(s,s5,s6) + XCfE1(0,0,s,0,s6) - XCfE1(0,0,s,s5,s6)))/2.;
}
double I3EM1s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(2*((-(log(s5)*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) +
            log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))) + pow(log(s5),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
       pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE0(s,0,s6)
      - (-(log(s5)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
            log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))) + pow(log(s5),2) + pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) +
       pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2)
       )*XCfE0(s,s5,s6)) + (-2*log(s5) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) +
    log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6) -
 (-2*log(s5) + log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
    log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1(0,0,s,s5,s6) + XCfE2(0,0,s,0,s6) - XCfE2(0,0,s,s5,s6)))/2.;
}
double I3E0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(2*(3*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2b(0,0,t(s),0,tl(s6),0)))*pow(log(s5),2) - 2*pow(log(s5),3) -
         6*log(s5)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
            pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2)) + 4*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3)))*XCfE0(s,0,s6) +
      2*(-3*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
            log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*pow(log(s5),2) + 2*pow(log(s5),3) +
         6*log(s5)*(pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2)) -
         4*(pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),3) +
            pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),3)))*XCfE0(s,s5,s6) +
      3*(2*(-(log(s5)*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
                 log(FA2b(0,0,t(s),0,tl(s6),0)))) + pow(log(s5),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
            pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*
          XCfE1(0,0,s,0,s6) - 2*(-(log(s5)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) +
                 log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))) + pow(log(s5),2) +
            pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2))*XCfE1(0,0,s,s5,s6) +
         (-2*log(s5) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE2(0,0,s,0,s6) +
         (2*log(s5) - log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) -
            log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE2(0,0,s,s5,s6) + XCfE3(0,0,s,0,s6) - XCfE3(0,0,s,s5,s6))))/6.;
}
