/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAi for the 3D integration at all eps-orders and the alpha^-1 order of the Rest-CA structure. 
 * Example: CAI3EP1AM1s ('CA' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'Plus '1'st and 'A'lpha to the 'M'inus '1'st  order, third integration over 's'5) 
 * contains various differences of logs of FXi functions evaluated at z=0,c=0,x=0, i.e. with deltas from all +-distributions except the t5/s5 one, multiplied 
 * with the correct XCA functions to arrive at eps^1 alpha^-1. 
 */

#include <3IntCAAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>
using namespace std;

//third integration is over t5 (s5 after rescaling)

double CAI3EM2AM1s(double w, double s6, double s5) {
	return (pow(s5,-1)*(-XCA00(w,s6,0,0,0) + XCA00(w,s6,s5,0,0)))/4.;
}

double CAI3EM1AM1s(double w, double s6, double s5) {
	return (pow(s5,-1)*((2*log(s5) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + 
       (-2*log(s5) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA00(w,s6,s5,0,0) - XCA01(w,s6,0,0,0) + 
       XCA01(w,s6,s5,0,0)))/4.;
}

double CAI3E0AM1s(double w, double s6, double s5) {
	return (pow(s5,-1)*(-2*(-(log(s5)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))) + pow(log(s5),2) + 
          pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) + 
       2*(-(log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))) + pow(log(s5),2) + 
          pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*
        XCA00(w,s6,s5,0,0) + 2*log(s5)*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - 
       2*log(s5)*XCA01(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) - 
       XCA02(w,s6,0,0,0) + XCA02(w,s6,s5,0,0)))/4.;
}

double CAI3EP1AM1s(double w, double s6, double s5) {
	return (pow(s5,-1)*(2*(-3*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*pow(log(s5),2) + 2*pow(log(s5),3) + 
          6*log(s5)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)) - 
          4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3)))*XCA00(w,s6,0,0,0) + 
       2*(3*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*pow(log(s5),2) - 2*pow(log(s5),3) - 
          6*log(s5)*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + 
             pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2)) + 4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),3) + 
             pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),3)))*XCA00(w,s6,s5,0,0) - 
       3*(2*(-(log(s5)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))) + pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + 
             pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA01(w,s6,0,0,0) - 
          2*(-(log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))) + pow(log(s5),2) + 
             pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*
           XCA01(w,s6,s5,0,0) - 2*log(s5)*XCA02(w,s6,0,0,0) + log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA02(w,s6,0,0,0) + 
          2*log(s5)*XCA02(w,s6,s5,0,0) - log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA02(w,s6,s5,0,0) + 
          XCA03(w,s6,0,0,0) - XCA03(w,s6,s5,0,0))))/12.;
}
//third integration is over u (z after rescaling)

double CAI3EM2AM1z(double w, double s6, double z) {
	return (pow(z,-1)*(-XCA00(w,s6,0,0,0) + XCA00(w,s6,0,z,0)))/2.;
}

double CAI3EM1AM1z(double w, double s6, double z) {
	return (pow(z,-1)*((4*log(z) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + 
       (-4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)))*XCA00(w,s6,0,z,0) - XCA01(w,s6,0,0,0) + 
       XCA01(w,s6,0,z,0)))/2.;
}

double CAI3E0AM1z(double w, double s6, double z) {
	return (pow(z,-1)*(-2*(-2*log(z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + 4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + 
          pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) + 
       2*(-2*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)) + 4*pow(log(z),2) + 
          pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*
        XCA00(w,s6,0,z,0) + 4*log(z)*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - 
       4*log(z)*XCA01(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) - 
       XCA02(w,s6,0,0,0) + XCA02(w,s6,0,z,0)))/2.;
}

double CAI3EP1AM1z(double w, double s6, double z) {
	return (pow(z,-1)*(8*(-3*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*pow(log(z),2) + 4*pow(log(z),3) - 
          pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + 
          3*log(z)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)) - 
          pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA00(w,s6,0,0,0) - 8*(-3*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*
             FB2(v(w),tl(s6),0,0,u(z),0))*pow(log(z),2) + 4*pow(log(z),3) - pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),3) - pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),3) - 
          pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),3) + 3*log(z)*(pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + 
             pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2)) - pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),3))*XCA00(w,s6,0,z,0) - 
       3*(2*(-2*log(z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + 4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + 
             pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA01(w,s6,0,0,0) - 
          2*(-2*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)) + 4*pow(log(z),2) + 
             pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*
           XCA01(w,s6,0,z,0) - 4*log(z)*XCA02(w,s6,0,0,0) + log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA02(w,s6,0,0,0) + 
          4*log(z)*XCA02(w,s6,0,z,0) - log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA02(w,s6,0,z,0) + 
          XCA03(w,s6,0,0,0) - XCA03(w,s6,0,z,0))))/6.;
}

//third integration is over b (c after rescaling)

double CAI3EM2AM1c(double w, double s6, double c) {
	return (pow(c,-1)*(-XCA00(w,s6,0,0,0) + XCA00(w,s6,0,0,c)))/2.;
}

double CAI3EM1AM1c(double w, double s6, double c) {
	return (pow(c,-1)*((4*log(c) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + 
       (-4*log(c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XCA00(w,s6,0,0,c) - XCA01(w,s6,0,0,0) + 
       XCA01(w,s6,0,0,c)))/2.;
}

double CAI3E0AM1c(double w, double s6, double c) {
	return (pow(c,-1)*(-2*(-2*log(c)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + 4*pow(log(c),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + 
          pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) + 
       2*(-2*log(c)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 4*pow(log(c),2) + 
          pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
        XCA00(w,s6,0,0,c) + 4*log(c)*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - 
       4*log(c)*XCA01(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) - 
       XCA02(w,s6,0,0,0) + XCA02(w,s6,0,0,c)))/2.;
}

double CAI3EP1AM1c(double w, double s6, double c) {
	return (pow(c,-1)*(8*(-3*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*pow(log(c),2) + 4*pow(log(c),3) - 
          pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + 
          3*log(c)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)) - 
          pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA00(w,s6,0,0,0) - 8*(-3*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*
             FB2(v(w),tl(s6),0,0,0,b(c)))*pow(log(c),2) + 4*pow(log(c),3) - pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) - pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) - 
          pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + 3*log(c)*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + 
             pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)) - pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*XCA00(w,s6,0,0,c) - 
       3*(2*(-2*log(c)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)) + 4*pow(log(c),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + 
             pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA01(w,s6,0,0,0) - 
          2*(-2*log(c)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 4*pow(log(c),2) + 
             pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
           XCA01(w,s6,0,0,c) - 4*log(c)*XCA02(w,s6,0,0,0) + log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA02(w,s6,0,0,0) + 
          4*log(c)*XCA02(w,s6,0,0,c) - log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA02(w,s6,0,0,c) + 
          XCA03(w,s6,0,0,0) - XCA03(w,s6,0,0,c))))/6.;
}

//third integration over x prohibited, since then no 1/alpha would be generated
