/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 5D integration at all eps-orders and the alpha^0 order of the Rest-CA structure. 
 * Example: CAI5EM1x ('CA' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'M'inus '1'st and alpha^0 order, with the only missing integration over 'x') 
 * contains various differences of logs of FXi functions evaluated at x=0, i.e. with only the delta arising from the y/x +-distribution, multiplied 
 * with the correct XCA functions to arrive at eps^-1 alpha^0. 
 */

#include <5IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

//missing integration x

double CAI5E0x(double w,double s6,double z,double s5,double c) {
	return 2*pow(c,-1)*pow(s5,-1)*pow(z,-1)*(4*log(c)*XCA00(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA00(w,s6,0,0,0) - 
     4*log(c)*XCA00(w,s6,0,0,c) + (log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 2*log(pow(1 + pow(c,2),2)))*
      XCA00(w,s6,0,0,c) - 4*log(c)*XCA00(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)*RegulA(0,z,w)*
        RegulB(0,z,w))*XCA00(w,s6,0,z,0) + 4*log(c)*XCA00(w,s6,0,z,c) - log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*
        FB2(v(w),tl(s6),0,0,u(z),b(c))*RegulA(c,z,w)*RegulB(c,z,w))*XCA00(w,s6,0,z,c) - 4*log(c)*XCA00(w,s6,s5,0,0) + 
     log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + 4*log(c)*XCA00(w,s6,s5,0,c) - 
     (log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))) + 2*log(pow(1 + pow(c,2),2)))*
      XCA00(w,s6,s5,0,c) + 4*log(c)*XCA00(w,s6,s5,z,0) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*
        FB2(v(w),tl(s6),0,t5(s5),u(z),0)*RegulA(0,z,w)*RegulB(0,z,w))*XCA00(w,s6,s5,z,0) - 4*log(c)*XCA00(w,s6,s5,z,c) + 
     log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB2(v(w),tl(s6),0,t5(s5),u(z),b(c))*RegulA(c,z,w)*RegulB(c,z,w))*
      XCA00(w,s6,s5,z,c));
}

//missing integration s5

double CAI5E0s(double w,double s6,double x,double z,double c) {
	return 2*mexp*pow(c,-1)*pow(x,-1)*pow(z,-1)*(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*
        pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA00(w,s6,0,0,0) + 
     log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c))*pow(FA1(v(w),tl(s6),0,0,0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,0,b(c)),-1))*XCA00(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),y(x),0,u(z),0)*FA2(v(w),tl(s6),y(x),0,u(z),0)*FB1(v(w),tl(s6),y(x),0,u(z),0)*FB2(v(w),tl(s6),y(x),0,u(z),0)*pow(FA1(v(w),tl(s6),0,0,u(z),0),-1)*
        pow(FA2(v(w),tl(s6),0,0,u(z),0),-1)*pow(FB1(v(w),tl(s6),0,0,u(z),0),-1)*pow(FB2(v(w),tl(s6),0,0,u(z),0),-1))*XCA00(w,s6,0,z,0) + 
     log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c))*pow(FA1(v(w),tl(s6),y(x),0,u(z),b(c)),-1)*
        pow(FA2(v(w),tl(s6),y(x),0,u(z),b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),0,u(z),b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),0,u(z),b(c)),-1))*XCA00(w,s6,0,z,c));
}

//missing integration z

double CAI5E0z(double w,double s6,double x,double s5,double c) {
	return mexp*pow(c,-1)*pow(s5,-1)*pow(x,-1)*(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*
        pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA00(w,s6,0,0,0) + 
     log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c))*pow(FA1(v(w),tl(s6),0,0,0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,0,b(c)),-1))*XCA00(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)*FA2(v(w),tl(s6),y(x),t5(s5),0,0)*FB1(v(w),tl(s6),y(x),t5(s5),0,0)*FB2(v(w),tl(s6),y(x),t5(s5),0,0)*pow(FA1(v(w),tl(s6),0,t5(s5),0,0),-1)*
        pow(FA2(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB1(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB2(v(w),tl(s6),0,t5(s5),0,0),-1))*XCA00(w,s6,s5,0,0) + 
     log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))*pow(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1))*XCA00(w,s6,s5,0,c));
}

//missing integration c

double CAI5E0c(double w,double s6,double x,double z,double s5) {
	return mexp*pow(s5,-1)*pow(x,-1)*pow(z,-1)*(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*
        pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA00(w,s6,0,0,0) + 
     log(FA1(v(w),tl(s6),y(x),0,u(z),0)*FA2(v(w),tl(s6),y(x),0,u(z),0)*FB1(v(w),tl(s6),y(x),0,u(z),0)*FB2(v(w),tl(s6),y(x),0,u(z),0)*pow(FA1(v(w),tl(s6),0,0,u(z),0),-1)*
        pow(FA2(v(w),tl(s6),0,0,u(z),0),-1)*pow(FB1(v(w),tl(s6),0,0,u(z),0),-1)*pow(FB2(v(w),tl(s6),0,0,u(z),0),-1))*XCA00(w,s6,0,z,0) + 
     log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)*FA2(v(w),tl(s6),y(x),t5(s5),0,0)*FB1(v(w),tl(s6),y(x),t5(s5),0,0)*FB2(v(w),tl(s6),y(x),t5(s5),0,0)*pow(FA1(v(w),tl(s6),0,t5(s5),0,0),-1)*
        pow(FA2(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB1(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB2(v(w),tl(s6),0,t5(s5),0,0),-1))*XCA00(w,s6,s5,0,0) + 
     log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0)*pow(FA1(v(w),tl(s6),y(x),t5(s5),u(z),0),-1)*
        pow(FA2(v(w),tl(s6),y(x),t5(s5),u(z),0),-1)*pow(FB1(v(w),tl(s6),y(x),t5(s5),u(z),0),-1)*pow(FB2(v(w),tl(s6),y(x),t5(s5),u(z),0),-1))*XCA00(w,s6,s5,z,0));
}
