/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNfij for the 4D integration at all eps-orders and the alpha^-1 order of the pseudo-nf structure. 
 * Example: PNfI4EP1AM1s ('P'seudo-'Nf' structure, 'I'ntegration over '4' dimensions, at 'E'ps to the 'Plus '1'st and 'A'lpha to the 'M'inus '1'st order, fourth integration over 's'5) 
 * contains logs of FXi functions evaluated at z=0,x=0, i.e. with the deltas from all +-distributions except the t5/s5 one, multiplied 
 * with the correct XPNf functions to arrive at eps^-1 alpha^-1. 
 */

#include <4IntPNFAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>

//fourth integration is over x doesn't occur, 1/alpha missing

//fourth integration is over s5

double PNfI4EM2AM1s(double w, double s6, double s5, double c) {
	return 0;
}

double PNfI4EM1AM1s(double w, double s6, double s5, double c) {
	return 2*pow(s5,-1)*(XPNf0(w,s6,0,0,c) - XPNf0(w,s6,s5,0,c));
}

double PNfI4E0AM1s(double w, double s6, double s5, double c) {
	return -2*pow(s5,-1)*((2*log(s5) - log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf0(w,s6,0,0,c) + 
     (-2*log(s5) + log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))))*XPNf0(w,s6,s5,0,c) - XPNf1(w,s6,0,0,c) + 
     XPNf1(w,s6,s5,0,c));
}

double PNfI4EP1AM1s(double w, double s6, double s5, double c) {
	return 2*pow(s5,-1)*(2*(-(log(s5)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))) + pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + 
        pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf0(w,s6,0,0,c) - 
     2*(-(log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))) + pow(log(s5),2) + 
        pow(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))),2))*XPNf0(w,s6,s5,0,c)\
      - 2*log(s5)*XPNf1(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XPNf1(w,s6,0,0,c) + 2*log(s5)*XPNf1(w,s6,s5,0,c) - 
     log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XPNf1(w,s6,s5,0,c) + XPNf2(w,s6,0,0,c) - XPNf2(w,s6,s5,0,c));
}

//fourth integration is over z

double PNfI4EM2AM1z(double w, double s6, double z, double c) {
	return 0;
}

double PNfI4EM1AM1z(double w, double s6, double z, double c) {
	return 4*pow(z,-1)*(XPNf0(w,s6,0,0,c) - XPNf0(w,s6,0,z,c));
}

double PNfI4E0AM1z(double w, double s6, double z, double c) {
	return -4*pow(z,-1)*((4*log(z) - log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf0(w,s6,0,0,c) + 
     (-4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c))))*XPNf0(w,s6,0,z,c) - XPNf1(w,s6,0,0,c) + XPNf1(w,s6,0,z,c));
}

double PNfI4EP1AM1z(double w, double s6, double z, double c) {
	return 4*pow(z,-1)*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf0(w,s6,0,0,c) + 
     8*pow(log(z),2)*(XPNf0(w,s6,0,0,c) - XPNf0(w,s6,0,z,c)) - 2*(pow(log(FA1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),b(c))),2) + 
        pow(log(FB2(v(w),tl(s6),0,0,u(z),b(c))),2))*XPNf0(w,s6,0,z,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XPNf1(w,s6,0,0,c) - 
     4*log(z)*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XPNf0(w,s6,0,0,c) - 
        log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XPNf0(w,s6,0,z,c) + XPNf1(w,s6,0,0,c) - XPNf1(w,s6,0,z,c)) - 
     log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XPNf1(w,s6,0,z,c) + XPNf2(w,s6,0,0,c) - XPNf2(w,s6,0,z,c));
}
