/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 5D integration at all eps-orders and the alpha^-1 order of the Rest-CA structure. 
 * Example: CAI5EP1AM1x ('CA' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'P'lus '1'st and 'A'lpha to the 'M'inus '1'st order, with the only missing integration over 'x') 
 * contains various differences of logs of FXi functions evaluated at x=0, i.e. with only the delta arising from the y/x +-distribution, multiplied 
 * with the correct XCA functions to arrive at eps^1 alpha^-1. 
 */


#include <5IntCAAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

//missing integration x

double CAI5E0AM1x(double w,double s6,double z,double s5,double c) {
	return -8*pow(c,-1)*pow(s5,-1)*pow(z,-1)*(XCA0(w,s6,0,0,0) - XCA0(w,s6,0,0,c) - XCA0(w,s6,0,z,0) + XCA0(w,s6,0,z,c) - XCA0(w,s6,s5,0,0) + XCA0(w,s6,s5,0,c) + XCA0(w,s6,s5,z,0) - XCA0(w,s6,s5,z,c));
}

double CAI5EP1AM1x(double w,double s6,double z,double s5,double c) {
	return 8*pow(c,-1)*pow(s5,-1)*pow(z,-1)*((2*log(s5) + 4*log(c*z) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0) + 
     (-2*log(s5) - 4*log(c*z) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XCA0(w,s6,0,0,c) - 2*log(s5)*XCA0(w,s6,0,z,0) - 
     4*log(c*z)*XCA0(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0) + 2*log(s5)*XCA0(w,s6,0,z,c) + 
     4*log(c*z)*XCA0(w,s6,0,z,c) - log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA0(w,s6,0,z,c) - 2*log(s5)*XCA0(w,s6,s5,0,0) - 
     4*log(c*z)*XCA0(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) + 2*log(s5)*XCA0(w,s6,s5,0,c) + 
     4*log(c*z)*XCA0(w,s6,s5,0,c) - log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c) + 
     2*log(s5)*XCA0(w,s6,s5,z,0) + 4*log(c*z)*XCA0(w,s6,s5,z,0) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*
      XCA0(w,s6,s5,z,0) - 2*log(s5)*XCA0(w,s6,s5,z,c) - 4*log(c*z)*XCA0(w,s6,s5,z,c) + 
     log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XCA0(w,s6,s5,z,c) - XCA1(w,s6,0,0,0) + XCA1(w,s6,0,0,c) + 
     XCA1(w,s6,0,z,0) - XCA1(w,s6,0,z,c) + XCA1(w,s6,s5,0,0) - XCA1(w,s6,s5,0,c) - XCA1(w,s6,s5,z,0) + XCA1(w,s6,s5,z,c));
}
//missing integration s5 irrelevant, if x is integrated, there's no 1/alpha

//missing integration z irrelevant, if x is integrated, there's no 1/alpha

//missing integration c irrelevant, if x is integrated, there's no 1/alpha
