/*
 * This file contains the eps-expansion of all functions and expressions in the Pseudo-Nf colour structure that are neither +-distributions or measurement functions 
 * (i.e. mainly structures from Jacobians and matrix element numerators, and non-divergent denominator structures), collected into one container XPNf. The 
 * eps- and alpha-expansion orders of this container appear in the differences generated by +-distributions and multiply the Logs of the measurement functions. They are 
 * constructed by substitution of variables in such a way to vanish at all non-critical boundaries (i.e. boundaries that have diverging logs attached, like 
 * Log(w) at 0 or Log(1-z) at 1. As C++ sees x*Log(x) as 0*NaN, these have to be caught via if-clauses for all but the first eps- and alpha-order.
 * The notation is such that XPNfij is the alpha^i eps^j order of these functions.
 */

#include <XFactorNf.h>
#include <cmath>
#include <Auxiliaries.h>
#include <Input_Common.h>
using namespace std;

double XPNf0(double w,double s6,double s5,double z,double c) {
	return (1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*pow(c,3)*(1 + pow(s6,2))*pow(1 - w,2)*pow(1 + w,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)))*
   pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,2),2)*pow(1 + pow(w,4),-3)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*
   pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*pow(2 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
   pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-2)*
   pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-2);
}

double XPNf1(double w,double s6,double s5,double z,double c) {
	if(s6<=0. || s6>=1. || w<=0. || z>=1. || c<=0.) {
		return 0;
	} else {
		return (1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*log(pow(c,-4)*pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2))*pow(c,3)*(1 + pow(s6,2))*pow(1 - w,2)*pow(1 + w,2)*
   (1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)))*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*
   pow(1 + pow(w,2),2)*pow(1 + pow(w,4),-3)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
   pow(2 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
   pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-2)*
   pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-2);
	}
}

double XPNf2(double w,double s6,double s5,double z,double c) {
	if(s6<=0. || s6>=1. || w<=0. || z>=1. || c<=0.) {
		return 0;
	} else {
		return ((1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*pow(c,3)*(1 + pow(s6,2))*pow(1 - w,2)*pow(1 + w,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)))*
     pow(log(pow(c,-4)*pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*
        pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
        pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
        pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2)),2)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,2),2)*pow(1 + pow(w,4),-3)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
     pow(2 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-2)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-2))/2.;
	}
}

double XPNf3(double w,double s6,double s5,double z,double c) {
	if(s6<=0. || s6>=1. || w<=0. || z>=1. || c<=0.) {
		return 0;
	} else {
		return ((1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*pow(c,3)*(1 + pow(s6,2))*pow(1 - w,2)*pow(1 + w,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)))*
     pow(log(pow(c,-4)*pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*
        pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
        pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
        pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2)),3)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,2),2)*pow(1 + pow(w,4),-3)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
     pow(2 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-2)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-2))/6.;
	}
}
