/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 4D integration at all eps-orders and the alpha^0 order of the Cf^2 structure, subregion a. 
 * Example: I4EM1A0rx ('I'ntegration over '4' dimensions, at 'E'ps to the 'M'inus '1'st and 'A'lpha to the '0'th order, third and fourth integrations over 
 * 'r' and 'x') contains various logs of FXi functions evaluated at c=0,s5=0, i.e. with the two deltas from the c and s5 +-distributions, multiplied 
 * with the correct X functions' eps- and alpha-powers to arrive at eps^-1 alpha^0. 
 */

#include <4Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I4EM2A0rx(double r, double x, double s, double s6) {
	return 0; //no alpha-poles, but leading order is xi-indep
}
double I4EM1A0rx(double r, double x, double s, double s6) {
	return (pow(r,-1)*pow(x,-1)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
	          log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),0)) -
	          log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),0)) +
	          log(FA2b(q(r),y(x),t(s),0,tl(s6),0)))*XCfE0A0(s,0,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,x,s,0,s6) - XCfE1A0(r,0,s,0,s6) + XCfE1A0(r,x,s,0,s6)))/2.;
}
double I4E0A0rx(double r, double x, double s, double s6) {
	return (pow(r,-1)*pow(x,-1)*(2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(q(r),y(x),t(s),0,tl(s6),0)),2) +
	          pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),y(x),t(s),0,tl(s6),0)),2) +
	          pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(q(r),y(x),t(s),0,tl(s6),0)),2) +
	          pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(q(r),y(x),t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) +
	       (log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1A0(0,0,s,0,s6) -
	       (log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE1A0(0,x,s,0,s6) -
	       (log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE1A0(r,0,s,0,s6) +
	       (log(FA1a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA1b(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2b(q(r),y(x),t(s),0,tl(s6),0)))*XCfE1A0(r,x,s,0,s6) + XCfE2A0(0,0,s,0,s6) -
	       XCfE2A0(0,x,s,0,s6) - XCfE2A0(r,0,s,0,s6) + XCfE2A0(r,x,s,0,s6)))/2.;
}

double I4EM2A0rc(double c, double r, double s, double s6) {
	return 0; //one alpha pole, which can be cancelled, but not converted
}
double I4EM1A0rc(double c, double r, double s, double s6) {
	return (-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) - log(FA1b(0,0,t(s),0,tl(s6),0)) +
		     log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) - log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),b(c))) +
		     log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(q(r),0,t(s),0,tl(s6),0)) -
		     log(FA2b(q(r),0,t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-1)*pow(r,-1)*XCfE0A0(s,0,s6);
}
double I4E0A0rc(double c, double r, double s, double s6) {
	return pow(c,-1)*pow(mexp,-1)*pow(r,-1)*((mexp*log(r)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) -
	           log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA2b(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),b(c)))) +
	        8*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
	           log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) -
	           log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(q(r),0,t(s),0,tl(s6),0)) +
	           log(FA2b(q(r),0,t(s),0,tl(s6),b(c)))) - 4*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) +
	           pow(log(FA1a(q(r),0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) +
	           pow(log(FA1b(q(r),0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) +
	           pow(log(FA2a(q(r),0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2) +
	           pow(log(FA2b(q(r),0,t(s),0,tl(s6),b(c))),2)))*XCfE0A0(s,0,s6) - (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*(2*XCfE0A1(0,0,s,0,s6) + XCfE1A0(0,0,s,0,s6)) +
	     (log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) -
	        log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2b(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),b(c))))*(2*XCfE0A1(r,0,s,0,s6) + XCfE1A0(r,0,s,0,s6)));
}

double I4EM2A0rs(double r, double s, double s5, double s6) {
	return 0; // one alpha pole, but leading order is r-indep
}
double I4EM1A0rs(double r, double s, double s5, double s6) {
	return (pow(mexp,-1)*pow(r,-1)*pow(s5,-1)*(-2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(0,0,s,s5,s6) + 2*XCfE0A1(r,0,s,0,s6) - 2*XCfE0A1(r,0,s,s5,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6) - XCfE1A0(r,0,s,0,s6) +
		       XCfE1A0(r,0,s,s5,s6)))/2.;
}
double I4E0A0rs(double r, double s, double s5, double s6) {
	return (pow(mexp,-1)*pow(r,-1)*pow(s5,-1)*((mexp*log(r)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) -
            log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0))) -
         2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)))*XCfE0A0(s,0,s6) +
      (mexp*log(r)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) -
            log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0))) +
         2*(pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)),2)))*
       XCfE0A0(s,s5,s6) + (4*log(s5) - 2*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0))))*XCfE0A1(0,0,s,0,s6) +
      2*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE0A1(0,0,s,s5,s6) -
      2*(log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)))*XCfE0A1(r,0,s,s5,s6) +
      2*(-2*log(s5)*XCfE0A1(0,0,s,s5,s6) + (-2*log(s5) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*
          XCfE0A1(r,0,s,0,s6) + 2*log(s5)*XCfE0A1(r,0,s,s5,s6)) - (mexp*log(r) + 2*log(s5))*(XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6) - XCfE1A0(r,0,s,0,s6) + XCfE1A0(r,0,s,s5,s6)) - 2*XCfE1A1(0,0,s,0,s6) +
      2*XCfE1A1(0,0,s,s5,s6) + 2*XCfE1A1(r,0,s,0,s6) - 2*XCfE1A1(r,0,s,s5,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,0,s,s5,s6) - XCfE2A0(r,0,s,0,s6) + XCfE2A0(r,0,s,s5,s6)))/2.;
}

double I4EM2A0xc(double c, double x, double s, double s6) {
	return 0; //leading order is x-indep
}
double I4EM1A0xc(double c, double x, double s, double s6) {
	return -2*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
		     log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) -
		     log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) +
		     log(FA2b(0,y(x),t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-1)*pow(x,-1)*XCfE0A0(s,0,s6);
}
double I4E0A0xc(double c, double x, double s, double s6) {
	return 2*pow(c,-1)*pow(mexp,-1)*pow(x,-1)*(2*(mexp*log(x)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) -
	           log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),b(c)))) +
	        4*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
	           log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) -
	           log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) +
	           log(FA2b(0,y(x),t(s),0,tl(s6),b(c)))) - 2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) +
	           pow(log(FA1a(0,y(x),t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) +
	           pow(log(FA1b(0,y(x),t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) +
	           pow(log(FA2a(0,y(x),t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2) +
	           pow(log(FA2b(0,y(x),t(s),0,tl(s6),b(c))),2)))*XCfE0A0(s,0,s6) - (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*(2*XCfE0A1(0,0,s,0,s6) + XCfE1A0(0,0,s,0,s6)) +
	     (log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) -
	        log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),b(c))))*(2*XCfE0A1(0,x,s,0,s6) + XCfE1A0(0,x,s,0,s6)));
}

double I4EM2A0xs(double x, double s, double s5, double s6) {
	return 0; //leading order is x-indep
}
double I4EM1A0xs(double x, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(s5,-1)*pow(x,-1)*(-2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(0,0,s,s5,s6) + 2*XCfE0A1(0,x,s,0,s6) - 2*XCfE0A1(0,x,s,s5,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6) - XCfE1A0(0,x,s,0,s6) +
		     XCfE1A0(0,x,s,s5,s6));
}
double I4E0A0xs(double x, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(s5,-1)*pow(x,-1)*(-2*(mexp*log(x)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) +
	           log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) -
	        pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) -
	        pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) +
	     (4*log(s5) - 2*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0))))*XCfE0A1(0,0,s,0,s6) +
	     2*((mexp*log(x)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) +
	              log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0))) +
	           pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)),2) +
	           pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)),2))*XCfE0A0(s,s5,s6)\
	         + (log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE0A1(0,0,s,s5,s6) -
	        (log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)))*XCfE0A1(0,x,s,s5,s6) +
	        mexp*log(x)*(-XCfE1A0(0,0,s,0,s6) + XCfE1A0(0,0,s,s5,s6) + XCfE1A0(0,x,s,0,s6) - XCfE1A0(0,x,s,s5,s6))) +
	     2*(-2*log(s5)*XCfE0A1(0,0,s,s5,s6) + (-2*log(s5) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*
	         XCfE0A1(0,x,s,0,s6) + log(s5)*(2*XCfE0A1(0,x,s,s5,s6) - XCfE1A0(0,0,s,0,s6) + XCfE1A0(0,0,s,s5,s6) + XCfE1A0(0,x,s,0,s6) - XCfE1A0(0,x,s,s5,s6))) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(0,0,s,s5,s6) +
	     2*XCfE1A1(0,x,s,0,s6) - 2*XCfE1A1(0,x,s,s5,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,0,s,s5,s6) - XCfE2A0(0,x,s,0,s6) + XCfE2A0(0,x,s,s5,s6));
}

double I4EM2A0cs(double c, double s, double s5, double s6) {
	return 0; //only alpha poles available, r and x are the only deltas
}
double I4EM1A0cs(double c, double s, double s5, double s6) {
	return 0; //only alpha poles available, r and x are the only deltas
}
double I4E0A0cs(double c, double s, double s5, double s6) {
	return 4*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*((-2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) -
	        pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) -
	        pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) +
	     (2*log(c)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) -
	           log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c)))) - pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) +
	        pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) +
	        pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))),2))*XCfE0A0(s,s5,s6) +
	     (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE0A1(0,0,s,0,s6) +
	     (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A1(0,0,s,s5,s6));
}

