/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 5D integration at all eps-orders and the alpha^-1 order of the Cf^2 structure, subregion a. 
 * Example: I5E0AM1s ('I'ntegration over '5' dimensions, at 'E'ps to the'0'th and 'A'lpha to the 'M'inus '1'st order, only missing integration over 's'5) 
 * contains various logs of FXi functions evaluated at s5=0, i.e. with only the delta from the s5 +-distribution, multiplied with the correct X functions' 
 * eps- and alpha-powers to arrive at eps^-0 alpha^-1. 
 */

#include <5IntAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I5E0AM1r(double c, double x, double s, double s5, double s6) {
	return 0;  //one pole from k, everything else loeading order
}
double I5E1AM1r(double c, double x, double s, double s5, double s6) {
	return -8*pow(c,-1)*pow(mexp,-1)*pow(s5,-1)*pow(x,-1)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) +
	        log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	        log(FA2a(0,0,t(s),0,tl(s6),b(c))) - log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) -
	        log(FA2b(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA1a(0,y(x),t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA1b(0,y(x),t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) +
	        log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA2a(0,y(x),t(s),t5(s5),tl(s6),b(c))) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)) -
	        log(FA2b(0,y(x),t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}

double I5E0AM1x(double c, double r, double s, double s5, double s6) {
	return 0; //one pole from l, everything else loeading order
}
double I5E1AM1x(double c, double r, double s, double s5, double s6) {
	return -4*pow(c,-1)*pow(mexp,-1)*pow(r,-1)*pow(s5,-1)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) +
	        log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	        log(FA2a(0,0,t(s),0,tl(s6),b(c))) - log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) -
	        log(FA2b(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA1a(q(r),0,t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA1b(q(r),0,t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) +
	        log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA2a(q(r),0,t(s),t5(s5),tl(s6),b(c))) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)) -
	        log(FA2b(q(r),0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}

//c contributes no alpha poles
double I5E0AM1c(double r, double x, double s, double s5, double s6) {
	return 0;
}
double I5E1AM1c(double r, double x, double s, double s5, double s6) {
	return 0;
}

//s contributes no alpha poles
double I5E0AM1s(double c, double r, double x, double s, double s6) {
	return 0;
}
double I5E1AM1s(double c, double r, double x, double s, double s6) {
	return 0;
}
