/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 4D integration at all eps-orders and the alpha^-1 order of the Cf^2 structure, subregion b. 
 * Example: I4E0AM1kl ('I'ntegration over '4' dimensions, at 'E'ps to the '0'th and 'A'lpha to the 'M'inus '1'st order, third and fourth integrations over 
 * x'k' and x'l') contains various logs of FXi functions evaluated at c=0,s5=0, i.e. with the two deltas from the c and s5 +-distributions, multiplied 
 * with the correct X functions' eps- and alpha-powers to arrive at eps^0 alpha^-1. 
 */

#include <4IntAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

//no alpha pole at all
double I4EM1AM1kl(double xk, double xl, double s, double s6) {
	return 0;
}
double I4E0AM1kl(double xk, double xl, double s, double s6) {
	return 0;
}
double I4E1AM1kl(double xk, double xl, double s, double s6) {
	return 0;
}

double I4EM1AM1kc(double c, double xk, double s, double s6) {
	return 0; //nothing to convert second pole
}
double I4E0AM1kc(double c, double xk, double s, double s6) {
	return -4*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) -
		     log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-1)*pow(xk,-1)*XCfE0A0(s,0,s6);
}
double I4E1AM1kc(double c, double xk, double s, double s6) {
	return 4*pow(c,-1)*pow(mexp,-1)*pow(xk,-1)*(2*(2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))) +
	           log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),b(c)))) - pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2) - pow(log(FB2(yk(xk),0,t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE1A0(0,0,s,0,s6) +
	     (log(FB1(yk(xk),0,t(s),0,tl(s6),0)) - log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))) + log(FB2(yk(xk),0,t(s),0,tl(s6),0)) - log(FB2(yk(xk),0,t(s),0,tl(s6),b(c))))*XCfE1A0(xk,0,s,0,s6));
}

double I4EM1AM1ks(double xk, double s, double s5, double s6) {
	return 0; //xl pole, leading order is xk-indep
}
double I4E0AM1ks(double xk, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(s5,-1)*pow(xk,-1)*(2*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0)))*XCfE0A0(s,0,s6) +
		     2*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0)))*XCfE0A0(s,s5,s6) - XCfE1A0(0,0,s,0,s6) +
		     XCfE1A0(0,0,s,s5,s6) + XCfE1A0(xk,0,s,0,s6) - XCfE1A0(xk,0,s,s5,s6));
}
double I4E1AM1ks(double xk, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(s5,-1)*pow(xk,-1)*(4*(log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(yk(xk),0,t(s),0,tl(s6),0))) -
	        pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) -
	     4*(log(s5)*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0))) -
	        pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0)),2))*XCfE0A0(s,s5,s6) +
	     2*((log(s5) - log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1A0(0,0,s,0,s6) + (-log(s5) + log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1A0(0,0,s,s5,s6) +
	        (-log(s5) + log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0)))*XCfE1A0(xk,0,s,0,s6) +
	        (log(s5) - log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)) - log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0)))*XCfE1A0(xk,0,s,s5,s6)) - XCfE2A0(0,0,s,0,s6) + XCfE2A0(0,0,s,s5,s6) + XCfE2A0(xk,0,s,0,s6) -
	     XCfE2A0(xk,0,s,s5,s6));
}

double I4EM1AM1lc(double c, double xl, double s, double s6) {
	return 0; //nothing to convert second pole
}
double I4E0AM1lc(double c, double xl, double s, double s6) {
	return -4*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) -
		     log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-1)*pow(xl,-1)*XCfE0A0(s,0,s6);
}
double I4E1AM1lc(double c, double xl, double s, double s6) {
	return 4*pow(c,-1)*pow(mexp,-1)*pow(xl,-1)*(2*(2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))) +
	           log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),b(c)))) - pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2) - pow(log(FB2(0,yl(xl),t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE1A0(0,0,s,0,s6) +
	     (log(FB1(0,yl(xl),t(s),0,tl(s6),0)) - log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))) + log(FB2(0,yl(xl),t(s),0,tl(s6),0)) - log(FB2(0,yl(xl),t(s),0,tl(s6),b(c))))*XCfE1A0(0,xl,s,0,s6));
}

double I4EM1AM1ls(double xl, double s, double s5, double s6) {
	return 0; // xk pole, c pole, leading order is xl-indep
}
double I4E0AM1ls(double xl, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(s5,-1)*pow(xl,-1)*(2*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0)))*XCfE0A0(s,0,s6) +
		     2*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0)))*XCfE0A0(s,s5,s6) - XCfE1A0(0,0,s,0,s6) +
		     XCfE1A0(0,0,s,s5,s6) + XCfE1A0(0,xl,s,0,s6) - XCfE1A0(0,xl,s,s5,s6));
}
double I4E1AM1ls(double xl, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(s5,-1)*pow(xl,-1)*(4*(log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,yl(xl),t(s),0,tl(s6),0))) -
	        pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) -
	     4*(log(s5)*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0))) -
	        pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)),2) - pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0)),2))*XCfE0A0(s,s5,s6) +
	     2*((log(s5) - log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1A0(0,0,s,0,s6) + (-log(s5) + log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1A0(0,0,s,s5,s6) +
	        (-log(s5) + log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0)))*XCfE1A0(0,xl,s,0,s6) +
	        (log(s5) - log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0)))*XCfE1A0(0,xl,s,s5,s6)) - XCfE2A0(0,0,s,0,s6) + XCfE2A0(0,0,s,s5,s6) + XCfE2A0(0,xl,s,0,s6) -
	     XCfE2A0(0,xl,s,s5,s6));
}

double I4EM1AM1cs(double c, double s, double s5, double s6) {
	return 0; //leading order, nothing to convert alpha pole
}
double I4E0AM1cs(double c, double s, double s5, double s6) {
	return 8*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
		     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}
double I4E1AM1cs(double c, double s, double s5, double s6) {
	return -8*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*(2*(4*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c)))) +
	        log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c)))) -
	        2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2)))*XCfE0A0(s,0,s6) +
	     2*(4*log(c)*(-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),b(c)))) +
	        log(s5)*(-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),b(c)))) +
	        2*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))),2)))*XCfE0A0(s,s5,s6) -
	     (log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*(2*XCfE0A1(0,0,s,0,s6) + XCfE1A0(0,0,s,0,s6)) +
	     (log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))))*(2*XCfE0A1(0,0,s,s5,s6) + XCfE1A0(0,0,s,s5,s6)));
}
