/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 5D integration at all eps-orders and the alpha^-1 order of the Cf^2 structure, subregion b. 
 * Example: I5E0AM1s ('I'ntegration over '5' dimensions, at 'E'ps to the'0'th and 'A'lpha to the 'M'inus '1'st order, only missing integration over 's'5) 
 * contains various logs of FXi functions evaluated at s5=0, i.e. with only the delta from the s5 +-distribution, multiplied with the correct X functions' 
 * eps- and alpha-powers to arrive at eps^-0 alpha^-1. 
 */

#include <5IntAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I5E0AM1k(double c, double xl, double s, double s5, double s6) {
	return 0;  //one pole from k, everything else loeading order
}
double I5E1AM1k(double c, double xl, double s, double s5, double s6) {
	return -8*pow(c,-1)*pow(mexp,-1)*pow(s5,-1)*pow(xl,-1)*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),b(c))) +
	        log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB1(0,yl(xl),t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),0)) - log(FB2(0,yl(xl),t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}

double I5E0AM1l(double c, double xk, double s, double s5, double s6) {
	return 0; //one pole from l, everything else loeading order
}
double I5E1AM1l(double c, double xk, double s, double s5, double s6) {
	return -8*pow(c,-1)*pow(mexp,-1)*pow(s5,-1)*pow(xk,-1)*((log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),b(c))) +
	        log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))) - log(FB2(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB1(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),0)) - log(FB1(yk(xk),0,t(s),t5(s5),tl(s6),b(c))) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FB2(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),0)) - log(FB2(yk(xk),0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}

//c contributes no alpha poles
double I5E0AM1c(double xk, double xl, double s, double s5, double s6) {
	return 0;
}
double I5E1AM1c(double xk, double xl, double s, double s5, double s6) {
	return 0;
}

//s contributes no alpha poles
double I5E0AM1s(double c, double xk, double xl, double s, double s6) {
	return 0;
}
double I5E1AM1s(double c, double xk, double xl, double s, double s6) {
	return 0;
}
